@@ -1,3 +1,6 @@
+
+op = par(no.readonly = TRUE)
+
 library(circlize)
 par(mar = c(1, 1, 1, 1))
 x = rnorm(2600)
@@ -9,3 +12,5 @@ circos.trackHist(factors = factors, x = x, draw.density = TRUE, track.height = 0
 circos.trackHist(factors = factors, x = x, draw.density = TRUE, force.ylim = FALSE, track.height = 0.1, col = "#999999", border = "#999999")
 
 circos.clear()
+
+par(op)
